pub struct ChannelNumber {
pub band: WlanBand,
pub number: u8,
}Expand description
Channel information consisting of the frequency band and the channel number.
Fields
band: WlanBandnumber: u8Trait Implementations
Sourceimpl Clone for ChannelNumber
impl Clone for ChannelNumber
Sourcefn clone(&self) -> ChannelNumber
fn clone(&self) -> ChannelNumber
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ChannelNumber
Sourceimpl Debug for ChannelNumber
impl Debug for ChannelNumber
Sourceimpl<D> Decode<ChannelNumber, D> for ChannelNumberwhere
D: ResourceDialect,
impl<D> Decode<ChannelNumber, D> for ChannelNumberwhere
D: ResourceDialect,
Sourcefn new_empty() -> ChannelNumber
fn new_empty() -> ChannelNumber
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ChannelNumber, D> for &ChannelNumberwhere
D: ResourceDialect,
impl<D> Encode<ChannelNumber, D> for &ChannelNumberwhere
D: ResourceDialect,
impl Eq for ChannelNumber
Sourceimpl Hash for ChannelNumber
impl Hash for ChannelNumber
Sourceimpl Ord for ChannelNumber
impl Ord for ChannelNumber
Sourcefn cmp(&self, other: &ChannelNumber) -> Ordering
fn cmp(&self, other: &ChannelNumber) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChannelNumber
impl PartialEq for ChannelNumber
Sourcefn eq(&self, other: &ChannelNumber) -> bool
fn eq(&self, other: &ChannelNumber) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ChannelNumber
impl PartialOrd for ChannelNumber
impl Persistable for ChannelNumber
impl StructuralPartialEq for ChannelNumber
Sourceimpl TypeMarker for ChannelNumber
impl TypeMarker for ChannelNumber
Sourcetype Owned = ChannelNumber
type Owned = ChannelNumber
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ChannelNumber
impl ValueTypeMarker for ChannelNumber
Sourcetype Borrowed<'a> = &'a ChannelNumber
type Borrowed<'a> = &'a ChannelNumber
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ChannelNumber as TypeMarker>::Owned,
) -> <ChannelNumber as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ChannelNumber as TypeMarker>::Owned, ) -> <ChannelNumber as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for ChannelNumber
impl RefUnwindSafe for ChannelNumber
impl Send for ChannelNumber
impl Sync for ChannelNumber
impl Unpin for ChannelNumber
impl UnsafeUnpin for ChannelNumber
impl UnwindSafe for ChannelNumber